generate_changing_data
============================================================

.. currentmodule:: skchange.datasets

.. autofunction:: generate_changing_data

.. include:: skchange.datasets.generate_changing_data.examples

.. raw:: html

    <div class="clearer"></div>